@@ -5,18 +5,19 @@
 import numpy as np
 import scipy
 import scipy.signal
-import scipy.fftpack
 
 from .. import util
 from .. import filters
 from ..util.exceptions import ParameterError
 
+from ..core.fft import get_fftlib
 from ..core.convert import fft_frequencies
 from ..core.audio import zero_crossings
 from ..core.spectrum import power_to_db, _spectrogram
 from ..core.constantq import cqt, hybrid_cqt, vqt
 from ..core.pitch import estimate_tuning
 from typing import Any, Optional, Union, Collection
+from typing_extensions import Literal
 from numpy.typing import DTypeLike
 from .._typing import _FloatLike_co, _WindowSpec, _PadMode, _PadModeSTFT
 
@@ -322,7 +323,8 @@ def spectral_bandwidth(
             "Spectral bandwidth is only defined " "with non-negative energies"
         )
 
-    # centroid or center?
+    # If we don't have a centroid provided, compute it using the existing
+    # spectrogram S
     if centroid is None:
         centroid = spectral_centroid(
             y=y, sr=sr, S=S, n_fft=n_fft, hop_length=hop_length, freq=freq
@@ -1108,7 +1110,7 @@ def zero_crossing_rate(
     array([[0.044, 0.074, ..., 0.488, 0.355]])
     """
     # check if audio is valid
-    util.valid_audio(y, mono=False)
+    util.valid_audio(y)
 
     if center:
         padding = [(0, 0) for _ in range(y.ndim)]
@@ -1838,6 +1840,7 @@ def mfcc(
     dct_type: int = 2,
     norm: Optional[str] = "ortho",
     lifter: float = 0,
+    mel_norm: Optional[Union[Literal["slaney"], float]] = "slaney",
     **kwargs: Any,
 ) -> np.ndarray:
     """Mel-frequency cepstral coefficients (MFCCs)
@@ -1869,6 +1872,7 @@ def mfcc(
             M[n, :] <- M[n, :] * (1 + sin(pi * (n + 1) / lifter) * lifter / 2)
         Setting ``lifter >= 2 * n_mfcc`` emphasizes the higher-order coefficients.
         As ``lifter`` increases, the coefficient weighting becomes approximately linear.
+    mel_norm : `norm` argument to `melspectrogram`
     **kwargs : additional keyword arguments to `melspectrogram`
         if operating on time series input
     n_fft : int > 0 [scalar]
@@ -1919,7 +1923,7 @@ def mfcc(
     See Also
     --------
     melspectrogram
-    scipy.fftpack.dct
+    scipy.fft.dct
 
     Examples
     --------
@@ -1986,9 +1990,10 @@ def mfcc(
     """
     if S is None:
         # multichannel behavior may be different due to relative noise floor differences between channels
-        S = power_to_db(melspectrogram(y=y, sr=sr, **kwargs))
+        S = power_to_db(melspectrogram(y=y, sr=sr, norm = mel_norm, **kwargs))
 
-    M: np.ndarray = scipy.fftpack.dct(S, axis=-2, type=dct_type, norm=norm)[
+    fft = get_fftlib()
+    M: np.ndarray = fft.dct(S, axis=-2, type=dct_type, norm=norm)[
         ..., :n_mfcc, :
     ]
 
